$TITLE MinCostBusSChedule OA4202 2011
$INLINECOM { }
 OPTIONS
   SOLPRINT =     OFF,
   DECIMALS =       1,
   LIMCOL   =      10,
   LIMROW   =      10,
   RESLIM   =      60, {max seconds}
   ITERLIM  =99999999, {max iterations}
   LP       =     COINCBC,
   MIP      =     COINCBC
 ;


$offlisting


$ontext
============================================================================
We define static sets for the nodes and arcs.  We also create some aliases for the nodes set.
============================================================================
$offtext

SET
    n   nodes  /
$INCLUDE  gams_nodesSet.csv
 /
 ;

alias(n,i,j)   {(i,j) is for describing arcs}

SET
    arcs(i,j)   arcs  /
$ONDELIM
$INCLUDE  gams_arcsSet.csv
$OFFDELIM
 /
 ;

$ontext
============================================================================
We create a list of acronyms that are going to appear as values in a data
table. Typically, GAMS only allows us to store real numbers as values in a
table.  If we want to store strings, as we do in this example, we have to first
declare all those strings as being acronyms.
============================================================================
$offtext

ACRONYMS
$INCLUDE  gams_acronyms.csv
;

$ontext
============================================================================
We now read in the data table for the arcs.
============================================================================
$offtext

table arcsdata(i,j,*)
$ONDELIM
$INCLUDE  gams_arcsData.csv
$OFFDELIM
;

$ontext
============================================================================
Now, we're ready to define the variables and constraints in our formulation.
============================================================================
$offtext

VARIABLE
  Z                 objective function value
;

POSITIVE VARIABLES
  Y(i,j)            flow on arc i j
;

EQUATIONS
  OBJECTIVE
  NETFLOW(n)
;

OBJECTIVE..
 Z =e= SUM(arcs(i,j), arcsdata(i,j,'Cost')*Y(i,j)) 
;

NETFLOW(j)..
 SUM(arcs(i,j), Y(i,j)) - SUM(arcs(j,i), Y(j,i)) =e= 0 - 1$(ord(j) eq 1) + 1$(ord(j) eq card(j))
;

MODEL ShortestPath
/
  OBJECTIVE
  NETFLOW
/;

$ontext
============================================================================
Now, lets solve for the shortest path.
============================================================================
$offtext

SOLVE ShortestPath USING LP MINIMIZING Z;       { find shortest path }

$ontext
============================================================================
Finally, lets print a report a file called min_cost_sched.out.  The report
will tell us who will cover what hours.
============================================================================
$offtext


file out /min_cost_sched.out/;
put out;

put 'Minimum Cost Schedule'/;
put '****' / ;
LOOP(arcs(i,j)$(Y.l(i,j)>0),
  put '   Time: ',i.tl, ' to ', j.tl, ' covered by ', arcsdata(i,j,'Person'),' at cost ', arcsdata(i,j,'Cost') / ;
);
put 'total cost=',Z.l:10:1 / ;



